@@ -143,12 +143,12 @@ class SharedData:
 
 
 class Pipe:
-    """Base class for all pipes. Provides utitilfdfites to work with configuration, validation etc.
+    """Base class for all pipes. Provides utilities to work with configuration, validation etc.
 
     Attributes:
         variables (dict): Dictionary containing the pipes variables.
         schema (dict): Dictionary with the pipe parameters shema in the cerberus format.
-        env (dict): Dict-like object conitining pipe parameters. This is usually the environment variables that
+        env (dict): Dict-like object containing pipe parameters. This is usually the environment variables that
             you get from os.environ
 
     Args:
@@ -336,6 +336,11 @@ class Pipe:
         env = {}
         for key, value in self.env.items():
             if key in schema:
+                # NOTE: we accept string as this
+                if schema[key].get('type', '') == 'string':
+                    env[key] = value
+                    continue
+
                 try:
                     env[key] = yaml.safe_load(value)
                 except yaml.scanner.ScannerError:
